<?php

namespace Testemail\Testmail\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Testemail\Testmail\Interfaces\TestemailRepositoryInterface;
use Testemail\Testmail\Repositories\Presenter\TestemailItemTransformer;

/**
 * Pubic API controller class.
 */
class TestemailPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Testemail\Testemail\Interfaces\TestemailRepositoryInterface $testemail
     *
     * @return type
     */
    public function __construct(TestemailRepositoryInterface $testemail)
    {
        $this->repository = $testemail;
        parent::__construct();
    }

    /**
     * Show testemail's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $testemails = $this->repository
            ->setPresenter('\\Testemail\\Testmail\\Repositories\\Presenter\\TestemailListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $testemails['code'] = 2000;
        return response()->json($testemails)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show testemail.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $testemail = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($testemail)) {
            $testemail         = $this->itemPresenter($module, new TestemailItemTransformer);
            $testemail['code'] = 2001;
            return response()->json($testemail)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
