<?php

namespace Testemail\Testmail\Http\Controllers;
use Litepie\Testmail\Http\Requests\TestemailRequest;
use Litepie\Testmail\Models\Testemail;

trait TestemailWorkflow {
	
    /**
     * Workflow controller function for testemail.
     *
     * @param Model   $testemail
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TestemailRequest $request, Testemail $testemail, $step)
    {

        try {

            $testemail->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('testmail::testemail.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/testemail/testemail/' . $testemail->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/testemail/testemail/' . $testemail->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for testemail.
     *
     * @param Model   $testemail
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Testemail $testemail, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $testemail->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('testmail::testemail.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testmail::admin.testemail.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testmail::admin.testemail.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testmail::admin.testemail.message', $data)->render();

        }

    }
}