<?php

namespace Testemail\Testmail\Policies;

use App\User;
use Testemail\Testmail\Models\Testemail;

class TestemailPolicy
{

    /**
     * Determine if the given user can view the testemail.
     *
     * @param User $user
     * @param Testemail $testemail
     *
     * @return bool
     */
    public function view(User $user, Testemail $testemail)
    {
        if ($user->canDo('testmail.testemail.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $testemail->user_id;
    }

    /**
     * Determine if the given user can create a testemail.
     *
     * @param User $user
     * @param Testemail $testemail
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('testmail.testemail.create');
    }

    /**
     * Determine if the given user can update the given testemail.
     *
     * @param User $user
     * @param Testemail $testemail
     *
     * @return bool
     */
    public function update(User $user, Testemail $testemail)
    {
        if ($user->canDo('testmail.testemail.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $testemail->user_id;
    }

    /**
     * Determine if the given user can delete the given testemail.
     *
     * @param User $user
     * @param Testemail $testemail
     *
     * @return bool
     */
    public function destroy(User $user, Testemail $testemail)
    {
        if ($user->canDo('testmail.testemail.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $testemail->user_id;
    }

    /**
     * Determine if the given user can verify the given testemail.
     *
     * @param User $user
     * @param Testemail $testemail
     *
     * @return bool
     */
    public function verify(User $user, Testemail $testemail)
    {
        if ($user->canDo('testmail.testemail.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('testmail.testemail.verify') 
        && $user->is('manager')
        && $testemail->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given testemail.
     *
     * @param User $user
     * @param Testemail $testemail
     *
     * @return bool
     */
    public function approve(User $user, Testemail $testemail)
    {
        if ($user->canDo('testmail.testemail.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
