<?php

namespace Testemail\Testmail\Providers;

use Illuminate\Support\ServiceProvider;

class TestmailServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'testmail');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'testmail');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('testmail', function ($app) {
            return $this->app->make('Testemail\Testmail\Testmail');
        });

        // Bind Testemail to repository
        $this->app->bind(
            \Testemail\Testmail\Interfaces\TestemailRepositoryInterface::class,
            \Testemail\Testmail\Repositories\Eloquent\TestemailRepository::class
        );

        $this->app->register(\Testemail\Testmail\Providers\AuthServiceProvider::class);
        $this->app->register(\Testemail\Testmail\Providers\EventServiceProvider::class);
        $this->app->register(\Testemail\Testmail\Providers\RouteServiceProvider::class);
        // $this->app->register(\Testemail\Testmail\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['testmail'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('testemail/testmail.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/testmail')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/testmail')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
