<?php

namespace Testemail\Testmail\Workflow;

use Testemail\Testmail\Models\Testemail;
use Validator;

class TestemailValidator
{

    /**
     * Determine if the given testemail is valid for complete status.
     *
     * @param Testemail $testemail
     *
     * @return bool / Validator
     */
    public function complete(Testemail $testemail)
    {
        return Validator::make($testemail->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given testemail is valid for verify status.
     *
     * @param Testemail $testemail
     *
     * @return bool / Validator
     */
    public function verify(Testemail $testemail)
    {
        return Validator::make($testemail->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given testemail is valid for approve status.
     *
     * @param Testemail $testemail
     *
     * @return bool / Validator
     */
    public function approve(Testemail $testemail)
    {
        return Validator::make($testemail->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given testemail is valid for publish status.
     *
     * @param Testemail $testemail
     *
     * @return bool / Validator
     */
    public function publish(Testemail $testemail)
    {
        return Validator::make($testemail->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given testemail is valid for archive status.
     *
     * @param Testemail $testemail
     *
     * @return bool / Validator
     */
    public function archive(Testemail $testemail)
    {
        return Validator::make($testemail->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given testemail is valid for unpublish status.
     *
     * @param Testemail $testemail
     *
     * @return bool / Validator
     */
    public function unpublish(Testemail $testemail)
    {
        return Validator::make($testemail->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
